@@ -81,6 +81,29 @@ describe Thor::Actions do
       expect(File.stat(original).mode).to eq(File.stat(copy).mode)
     end
 
+    it "shows the diff when there is a collision and source has utf-8 characters" do
+      previous_internal = Encoding.default_internal
+
+      silence_warnings do
+        Encoding.default_internal = Encoding::UTF_8
+      end
+
+      destination = File.join(destination_root, "encoding_with_utf8.thor")
+      FileUtils.mkdir_p(destination_root)
+
+      File.write(destination, "blabla")
+
+      expect(Thor::LineEditor).to receive(:readline).and_return("d", "y")
+      expect(runner.shell).to receive(:system).with(/diff -u/)
+      action :copy_file, "encoding_with_utf8.thor"
+
+      exists_and_identical?("encoding_with_utf8.thor", "encoding_with_utf8.thor")
+    ensure
+      silence_warnings do
+        Encoding.default_internal = previous_internal
+      end
+    end
+
     it "logs status" do
       expect(action(:copy_file, "command.thor")).to eq("      create  command.thor\n")
     end
@@ -293,6 +316,104 @@ describe Thor::Actions do
       end
     end
 
+    describe "#gsub_file!" do
+      context "with invoke behavior" do
+        it "replaces the content in the file" do
+          action :gsub_file!, "doc/README", "__start__", "START"
+          expect(File.binread(file)).to eq("START\nREADME\n__end__\n")
+        end
+
+        it "does not replace if pretending" do
+          runner(pretend: true)
+          action :gsub_file!, "doc/README", "__start__", "START"
+          expect(File.binread(file)).to eq("__start__\nREADME\n__end__\n")
+        end
+
+        it "accepts a block" do
+          action(:gsub_file!, "doc/README", "__start__") { |match| match.gsub("__", "").upcase }
+          expect(File.binread(file)).to eq("START\nREADME\n__end__\n")
+        end
+
+        it "logs status" do
+          expect(action(:gsub_file!, "doc/README", "__start__", "START")).to eq("        gsub  doc/README\n")
+        end
+
+        it "does not log status if required" do
+          expect(action(:gsub_file!, file, "__", verbose: false) { |match| match * 2 }).to be_empty
+        end
+
+        it "cares if the file contents did not change" do
+          expect do
+            action :gsub_file!, "doc/README", "___start___", "START"
+          end.to raise_error(Thor::Error, "The content of #{destination_root}/doc/README did not change")
+
+          expect(File.binread(file)).to eq("__start__\nREADME\n__end__\n")
+        end
+      end
+
+      context "with revoke behavior" do
+        context "and no force option" do
+          it "does not replace the content in the file" do
+            runner({}, :revoke)
+            action :gsub_file!, "doc/README", "__start__", "START"
+            expect(File.binread(file)).to eq("__start__\nREADME\n__end__\n")
+          end
+
+          it "does not replace if pretending" do
+            runner({pretend: true}, :revoke)
+            action :gsub_file!, "doc/README", "__start__", "START"
+            expect(File.binread(file)).to eq("__start__\nREADME\n__end__\n")
+          end
+
+          it "does not replace the content in the file when given a block" do
+            runner({}, :revoke)
+            action(:gsub_file!, "doc/README", "__start__") { |match| match.gsub("__", "").upcase }
+            expect(File.binread(file)).to eq("__start__\nREADME\n__end__\n")
+          end
+
+          it "does not log status" do
+            runner({}, :revoke)
+            expect(action(:gsub_file!, "doc/README", "__start__", "START")).to be_empty
+          end
+
+          it "does not log status if required" do
+            runner({}, :revoke)
+            expect(action(:gsub_file!, file, "__", verbose: false) { |match| match * 2 }).to be_empty
+          end
+        end
+
+        context "and force option" do
+          it "replaces the content in the file" do
+            runner({}, :revoke)
+            action :gsub_file!, "doc/README", "__start__", "START", force: true
+            expect(File.binread(file)).to eq("START\nREADME\n__end__\n")
+          end
+
+          it "does not replace if pretending" do
+            runner({pretend: true}, :revoke)
+            action :gsub_file!, "doc/README", "__start__", "START", force: true
+            expect(File.binread(file)).to eq("__start__\nREADME\n__end__\n")
+          end
+
+          it "replaces the content in the file when given a block" do
+            runner({}, :revoke)
+            action(:gsub_file!, "doc/README", "__start__", force: true) { |match| match.gsub("__", "").upcase }
+            expect(File.binread(file)).to eq("START\nREADME\n__end__\n")
+          end
+
+          it "logs status" do
+            runner({}, :revoke)
+            expect(action(:gsub_file!, "doc/README", "__start__", "START", force: true)).to eq("        gsub  doc/README\n")
+          end
+
+          it "does not log status if required" do
+            runner({}, :revoke)
+            expect(action(:gsub_file!, file, "__", verbose: false, force: true) { |match| match * 2 }).to be_empty
+          end
+        end
+      end
+    end
+
     describe "#gsub_file" do
       context "with invoke behavior" do
         it "replaces the content in the file" do
@@ -318,6 +439,11 @@ describe Thor::Actions do
         it "does not log status if required" do
           expect(action(:gsub_file, file, "__", verbose: false) { |match| match * 2 }).to be_empty
         end
+
+        it "does not care if the file contents did not change" do
+          action :gsub_file, "doc/README", "___start___", "START"
+          expect(File.binread(file)).to eq("__start__\nREADME\n__end__\n")
+        end
       end
 
       context "with revoke behavior" do
